@@ -5,6 +5,7 @@ from __future__ import absolute_import
 import sys
 import argparse
 import symstore
+from pathlib import Path
 
 
 class CompressionNotSupported(Exception):
@@ -23,12 +24,20 @@ def parse_args():
                         action="store_true",
                         help="Publish compressed files.")
 
+    parser.add_argument("-m", "--max-compress",
+                        type=int, default=None,
+                        help="Specifies maximum size of files to compress. "
+                             "File above the limit are published uncompressed.")
+
     parser.add_argument("-p", "--product-name", default="",
                         help="Name of the product.")
 
     parser.add_argument("-r", "--product-version", default="",
                         help="Version of the product.")
 
+    parser.add_argument("-c", "--comment", default="",
+                        help="Comment for the transaction.")
+
     parser.add_argument("-s", "--skip-published",
                         action="store_true",
                         default=False,
@@ -38,7 +47,7 @@ def parse_args():
 
     parser.add_argument("--version",
                         action="version",
-                        version="symstore %s" % symstore.VERSION,
+                        version="symstore %s" % symstore.__version__,
                         help="Show program's version number and exit.")
 
     parser.add_argument("store_path", metavar="STORE_PATH",
@@ -73,19 +82,41 @@ def delete_action(sym_store, transaction_id):
         err_exit("no transaction with id '%s' found" % transaction_id)
 
 
-def add_action(sym_store, files, product_name, product_version, compress,
-               skip_published):
+def add_action(sym_store, files,
+               product_name, product_version, comment,
+               compress, max_compress, skip_published):
+
+    def _compress_file(file):
+        """
+        makes a decision if the file should be published compressed
+        """
+
+        if not compress:
+            # compression is disabled for this transaction
+            return False
+
+        if max_compress is None:
+            # compression is enabled,
+            # but there is no file size specified
+            return True
+
+        # only compress if the file is inside
+        # the compression file size limit
+        file_size = Path(file).stat().st_size
+        return file_size <= max_compress
+
     try:
         # error-out if no compression
         check_compression_support(compress)
 
         # create new add transaction, add all specified files
-        transaction = sym_store.new_transaction(product_name, product_version)
+        transaction = sym_store.new_transaction(product_name, product_version,
+                                                comment)
         for file in files:
-            entry = transaction.new_entry(file, compress)
+            entry = transaction.new_entry(file, _compress_file(file))
 
             if skip_published and entry.exists():
-                # 'skip published' mode is on and this files
+                # 'skip published' mode is on and this file
                 # have already been published, skip it skipper
                 continue
 
@@ -110,6 +141,7 @@ def add_action(sym_store, files, product_name, product_version, compress,
 
 def main():
     args = parse_args()
+
     sym_store = symstore.Store(args.store_path)
 
     if args.delete is not None:
@@ -118,5 +150,6 @@ def main():
 
     # otherwise this is an 'add' action
     add_action(sym_store, args.files, args.product_name,
-               args.product_version, args.compress,
+               args.product_version, args.comment,
+               args.compress, args.max_compress,
                args.skip_published)
