@@ -5,9 +5,8 @@ class FileFormatError(Exception):
     pass
 
 
-class UnknownFileExtension(Exception):
-    def __init__(self, file_extension):
-        self.file_extension = file_extension
+class UnknownFileType(Exception):
+    pass
 
 
 class FileNotFound(Exception):
@@ -19,3 +18,9 @@ class TransactionNotFound(Exception):
     """
     raised when symstore does not contain transaction with specified ID
     """
+
+
+class CabCompressionError(Exception):
+    """
+    raised on error creating CAB archive
+    """
