@@ -4,6 +4,7 @@ import os
 import re
 import time
 import shutil
+from concurrent.futures import ThreadPoolExecutor
 from os import path
 from symstore import pe
 from symstore import pdb
@@ -52,7 +53,7 @@ def _pdb_hash(pdbfile):
 
 
 def _pe_hash(pefile):
-    return "%X%X" % (pefile.TimeDateStamp, pefile.SizeOfImage)
+    return "%X%x" % (pefile.TimeDateStamp, pefile.SizeOfImage)
 
 
 def _probe_pe_hash(fname):
@@ -250,9 +251,14 @@ class Transaction:
         self.timestamp = now
         self.id = id
 
-        # publish all entries files to the store
-        for entry in self.entries:
-            entry.publish()
+        #
+        # publish entries in parallel,
+        # doing it in parallel speeds up the commit operation
+        # when there are multiple entries,
+        # specially when compression is requested
+        #
+        with ThreadPoolExecutor() as e:
+            e.map(lambda entry: entry.publish(), self.entries)
 
         # write new transaction file
         with self._entries_file("a") as efile:
@@ -270,9 +276,9 @@ class Transaction:
         time_stamp = self.timestamp.strftime("%H:%M:%S")
 
         assert self._commited()
-        return """%s,%s,%s,%s,%s,"%s","%s","",""" % \
+        return """%s,%s,%s,%s,%s,"%s","%s","%s",""" % \
                (self.id, self.type, self.ref, date_stamp, time_stamp,
-                self.product, self.version)
+                self.product, self.version, self.comment)
 
 
 def parse_transaction_line(line):
@@ -557,8 +563,9 @@ class Store:
 
         os.utime(pingme_path, (timestamp, timestamp))
 
-    def new_transaction(self, product, version, type="add"):
-        return Transaction(self, type=type, product=product, version=version)
+    def new_transaction(self, product, version, comment, type="add"):
+        return Transaction(self, type=type, product=product,
+                           version=version, comment=comment)
 
     def delete_transaction(self, transaction_id):
         # look up the transaction to delete
